@@ -18,6 +18,7 @@ public:
     QString _country;   /*!< friend country (optional) */
     QString _icon;      /*!< path to friend avatar image */
     QString _icon_url;  /*!< url of friend avatar image */
+    QString _status_message; /*!< status message */
 
     //! A friend status.
     /*!
@@ -56,6 +57,7 @@ FriendData::FriendData(const FriendData& other)
     _mobilePhone = other._mobilePhone;
     _nickName = other._nickName;
     _online = other._online;
+    _status_message = other._status_message;
     _isMainProfile = other._isMainProfile;
     _profiles = other._profiles;
 
@@ -213,6 +215,16 @@ bool Friend::online() const
     return d->_online;
 }
 
+const QString Friend::statusMessage() const
+{
+    return d->_status_message;
+}
+
+void Friend::setStatusMessage(const QString &message)
+{
+    d->_status_message = message;
+}
+
 const QString Friend::name() const
 {
     QString ret = QObject::tr("Unknown");
@@ -375,6 +387,14 @@ QDomElement Friend::toQDomElement(QDomDocument& doc, const Friend& src, const bo
             ret.appendChild(node);
             node.appendChild(t);
         }
+
+        if (!src.statusMessage().isEmpty())
+        {
+            node = doc.createElement(NODE_FRIEND_STATUS);
+            t = doc.createTextNode(src.statusMessage());
+            ret.appendChild(node);
+            node.appendChild(t);
+        }
     }
 
     return ret;
@@ -408,6 +428,8 @@ Friend Friend::fromQDomElement(const QDomElement& fr, const QString& accountId_,
         ret.setCity(fr.elementsByTagName(NODE_FRIEND_CITY).at(0).firstChild().toText().data());
     if (fr.elementsByTagName(NODE_FRIEND_COUNTRY).count() > 0)
         ret.setCountry(fr.elementsByTagName(NODE_FRIEND_COUNTRY).at(0).firstChild().toText().data());
+    if (fr.elementsByTagName(NODE_FRIEND_STATUS).count() > 0)
+        ret.setStatusMessage(fr.elementsByTagName(NODE_FRIEND_STATUS).at(0).firstChild().toText().data());
     ret.setAccountId(accountId_);
     ret.setServiceId(serviceId_);
 
