@@ -41,6 +41,7 @@ class Friend;
 #define NODE_FRIEND_HOME_PHONE "homePhone"
 #define NODE_FRIEND_CITY "city"
 #define NODE_FRIEND_COUNTRY "country"
+#define NODE_FRIEND_STATUS "status"
 
 #define FILE_OWNER_DATA "owner_%1.xml"
 
@@ -236,6 +237,20 @@ public:
      */
     const QString icon() const;
 
+    /*!
+      \brief Sets friend's status message.
+
+      \param friend's status message
+     */
+    void setStatusMessage(const QString& message);
+
+    /*!
+      \brief Gets friend's status message.
+
+      \return friend's status message
+     */
+    const QString statusMessage() const;
+
     void setOwnerId(const QString& id);
     const QString ownerId() const;
 
