@@ -12,6 +12,7 @@
 #include <QMetaType>
 #include <QDebug>
 #include <QDomDocument>
+#include <QSharedData>
 
 #include "utils/qrefreshlist.h"
 
@@ -28,6 +29,8 @@
 #define NODE_MESSAGE_TIME "time"
 #define NODE_MESSAGE_TITLE "title"
 #define NODE_MESSAGE_STATUS "status"
+#define NODE_MESSAGE_SENDED "isSended"
+#define NODE_MESSAGE_RECEIVED "isReceived"
 #define NODE_ARRAY "array"
 #define NODE_STRUCT "struct"
 
@@ -42,6 +45,8 @@ struct Recepient {
     QString name; /*!< \brief The name of recepient */
 };
 
+class MessageData;
+
 /*!
  \brief A class for message information storage.
  */
@@ -50,9 +55,9 @@ struct Recepient {
 
  \class Message message.h "src/datatypes/message.h"
 */
-class Message : public QObject
+class Message
 {
-    Q_OBJECT
+    QSharedDataPointer<MessageData> d;
 public:
     /*!
      \brief
@@ -74,29 +79,13 @@ public:
     */
     ~Message();
 
-    QString messageId; /*!< TODO */
-    QString accountId; /*!< TODO */
-    QString senderId; /*!< TODO */
-    QString senderName; /*!< TODO */
-    QString threadId; /*!< TODO */
-
-    QList<Recepient> recepientList; /*!< TODO */
-
-    // message body
-    QString text; /*!< TODO */
-
-    // message title
-    QString title; /*!< TODO */
-
-    // date
-    QString time; /*!< TODO */
-
     /*!
      \brief
 
      \fn subject
     */
     const QString subject();
+
     /*!
      \brief
 
@@ -105,8 +94,6 @@ public:
     */
     QString subjectFromBody(QString messageBody);
 
-    QString status; /*!< TODO */
-
     // store data to XML format
     /*!
      \brief
@@ -143,6 +130,7 @@ public:
      \param
     */
     Message& operator=(const Message&);
+
     /*!
      \brief
 
@@ -153,15 +141,55 @@ public:
     static void copyData(Message *dst, const Message *src);
 
     /*!
-      \brief Check is message readed
-      \return true if readed, false otherwise
-    */
+      \brief Generate key based on account and message IDs.
+
+      \param accountId The ID of account.
+
+      \param messageId The ID of message.
+
+      \return The string key.
+      */
+    static QString readMessageKey(const QString& accountId, const QString& messageId);
+
+    /*!
+      \brief Generate key based on account and message IDs.
+
+      \param accountId The ID of account.
+
+      \param messageId The ID of message.
+
+      \return The string key.
+      */
+    static QString deleteMessageKey(const QString& accountId, const QString& messageId);
+
+    // Getters
+    const QString messageId() const;
+    const QString accountId() const;
+    const QString senderId() const;
+    const QString senderName() const;
+    const QString threadId() const;
+    QList<Recepient>& recepientList();
+    const QList<Recepient>& recepientListConst() const;
+    const QString text() const;
+    const QString title() const;
+    const QString time() const;
     bool isReaded() const;
+    bool isSended() const;
+    bool isReceived() const;
 
-signals:
-
-public slots:
-
+    // Setters
+    void setMessageId(const QString& v);
+    void setAccountId(const QString& v);
+    void setSenderId(const QString& v);
+    void setSenderName(const QString& v);
+    void setThreadId(const QString& v);
+    void setRecepientList(const QList<Recepient>& v);
+    void setText(const QString& v);
+    void setTitle(const QString& v);
+    void setTime(const QString& v);
+    void setReaded(const bool& v = true);
+    void setSended(const bool& v = true);
+    void setReceived(const bool& v = true);
 };
 
 /*! \typedef MessageList
