@@ -4,6 +4,7 @@
 #include <QObject>
 #include <QMetaType>
 #include <QDomDocument>
+#include <QSharedDataPointer>
 
 #include "utils/qrefreshlist.h"
 
@@ -17,30 +18,16 @@ typedef QRefreshList<PhotoComment> PhotoCommentList;
 #define NODE_PHOTO_COMMENT_TEXT "text"
 #define NODE_PHOTO_COMMENT_TIME "time"
 
-class PhotoComment : public QObject
+class PhotoCommentData;
+
+class PhotoComment
 {
-    Q_OBJECT
+    QSharedDataPointer<PhotoCommentData> d;
+
 public:
-    explicit PhotoComment(QObject *parent = 0);
+    explicit PhotoComment();
     PhotoComment(const PhotoComment& source);
-
-    QString accountId;
-
-    QString ownerId;
-
-    QString albumId;
-
-    QString photoId;
-
-    QString commentId;
-
-    QString senderId;
-
-    QString senderName;
-
-    QString time;
-
-    QString text;
+    ~PhotoComment();
 
     // store data to XML format
     QDomElement toQDomElement(QDomDocument doc);
@@ -51,14 +38,29 @@ public:
     // load photolist from XML struct
     static PhotoComment fromQDomElement(QDomElement fr, QString accountId, QString friendId, QString albumId, QString photoId);
 
-    static void copyData(PhotoComment *dst, const PhotoComment *src);
-
     PhotoComment& operator=(const PhotoComment& source);
 
-signals:
-
-public slots:
+    // Getters
+    const QString accountId() const;
+    const QString ownerId() const;
+    const QString albumId() const;
+    const QString photoId() const;
+    const QString commentId() const;
+    const QString senderId() const;
+    const QString senderName() const;
+    const QString time() const;
+    const QString text() const;
 
+    // Setters
+    void setAccountId(const QString& v);
+    void setOwnerId(const QString& v);
+    void setAlbumId(const QString& v);
+    void setPhotoId(const QString& v);
+    void setCommentId(const QString& v);
+    void setSenderId(const QString& v);
+    void setSenderName(const QString& v);
+    void setTime(const QString& v);
+    void setText(const QString& v);
 };
 
 Q_DECLARE_METATYPE(PhotoComment)
