@@ -16,7 +16,7 @@ class FilterMessageType : public Filter
     Q_ENUMS(MessageType)
 
 public:
-    enum MessageType {NEW, ALL, INBOX, OUTBOX, DRAFTS};
+    enum MessageType {ALL, INBOX, OUTBOX, DRAFTS};
 
     explicit FilterMessageType(ServiceMgr* mgr, QObject *parent = 0);
 
