@@ -72,11 +72,3 @@ void ServiceFilter::fillPanel()
             emit itemAdded(driver->name, driver);
     }
 }
-
-//TODO: remove UI from core
-/*
-void ServiceFilter::hideWidget(bool hide)
-{
-    this->filterPanel->setVisible(!hide);
-}
-*/
