@@ -1,5 +1,6 @@
 #include "qtransport.h"
 #include <QDebug>
+#include <QUrl>
 
 typedef  gint (*driver_init)(msa_module *);
 
@@ -679,9 +680,90 @@ void QTransport::getProfile(const QString& ownerId)
             }
         }
     }
+    this->getStatusMessage(profile);
+
     emit profileReceived(this->accId, ownerId, profile);
 }
 
+void QTransport::getStatusMessage()
+{
+    this->getStatusMessage(QString::null);
+}
+
+void QTransport::getStatusMessage(const QString &ownerId)
+{
+    qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << ": accountId=" << this->accId << "; ownerId=" << ownerId;
+    if (!this->checkFunction(CLASS_PROFILE, "getStatus", this->getProfileAction))
+        return;
+
+    QDomDocument req = this->createRequest(CLASS_PROFILE, "getStatus");
+    if (!ownerId.isEmpty()) {
+        QDomNodeList params = req.elementsByTagName("Params");
+        params.at(0).toElement().setAttribute("id", ownerId);
+    }
+    QDomDocument res = this->sendRequest(req, this->getProfileAction);
+
+    if (!this->checkBadResponse(res, this->getProfileAction))
+        return;
+
+    // parse response
+    if (res.elementsByTagName("Response").count() == 0 ||
+        res.elementsByTagName("Response").at(0).toElement().attribute("function").compare("getStatus") != 0)
+        return;
+
+    QDomElement params = res.elementsByTagName("Response").at(0).toElement().
+                         elementsByTagName("Params").at(0).toElement();
+    QDomNodeList paramNodes = params.childNodes();
+
+    QString statusMessage;
+
+    for (int i = 0; i < paramNodes.count(); i++) {
+        QDomElement curElem = paramNodes.at(i).toElement();
+        const QString curElemName = curElem.attribute("name");
+        if (curElem.nodeName().compare("string") == 0) {
+            if (curElemName.compare("Text") == 0)
+                statusMessage = curElem.firstChild().nodeValue().trimmed();
+        }
+    }
+
+    emit statusMessageReceived(this->accId, ownerId, statusMessage);
+}
+
+void QTransport::getStatusMessage(Friend &fr)
+{
+    qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << ": accountId=" << this->accId << "; ownerId=" << fr.ownerId();
+    if (!this->checkFunction(CLASS_PROFILE, "getStatus", this->getProfileAction))
+        return;
+
+    QDomDocument req = this->createRequest(CLASS_PROFILE, "getStatus");
+    if (!fr.ownerId().isEmpty()) {
+        QDomNodeList params = req.elementsByTagName("Params");
+        params.at(0).toElement().setAttribute("id", fr.ownerId());
+    }
+    QDomDocument res = this->sendRequest(req, this->getProfileAction);
+
+    if (!this->checkBadResponse(res, this->getProfileAction))
+        return;
+
+    // parse response
+    if (res.elementsByTagName("Response").count() == 0 ||
+        res.elementsByTagName("Response").at(0).toElement().attribute("function").compare("getStatus") != 0)
+        return;
+
+    QDomElement params = res.elementsByTagName("Response").at(0).toElement().
+                         elementsByTagName("Params").at(0).toElement();
+    QDomNodeList paramNodes = params.childNodes();
+
+    for (int i = 0; i < paramNodes.count(); i++) {
+        QDomElement curElem = paramNodes.at(i).toElement();
+        const QString curElemName = curElem.attribute("name");
+        if (curElem.nodeName().compare("string") == 0) {
+            if (curElemName.compare("Text") == 0)
+                fr.setStatusMessage(curElem.firstChild().nodeValue().trimmed());
+        }
+    }
+}
+
 void QTransport::setSettings(QString settings)
 {
     qDebug() << __FILE__<<":"<< __LINE__<<":" << __FUNCTION__ << ": accountId=" <<this->accId;
@@ -830,6 +912,39 @@ void QTransport::getAlbums(QString ownerId, bool alsoLoadIcons)
     emit albumsReceived(this->accId, ownerId, ret, true);
 }
 
+bool QTransport::createAlbum(QString name, QString description, QString privacy)
+{
+    qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << "name: " << name;
+    if (!this->checkFunction(CLASS_PHOTOS, CREATE_ALBUM, this->createAlbumAction))
+        return false;
+
+    QDomDocument req = this->createRequest(CLASS_PHOTOS, CREATE_ALBUM);
+
+    QDomElement params = req.elementsByTagName("Params").at(0).toElement();
+
+    QDomElement node = req.createElement("string");
+    node.setAttribute("name", "name");
+    node.appendChild(req.createTextNode(name));
+    params.appendChild(node);
+
+    node = req.createElement("string");
+    node.setAttribute("name", "description");
+    node.appendChild(req.createTextNode(description));
+    params.appendChild(node);
+
+    node = req.createElement("string");
+    node.setAttribute("name", "privacy");
+    node.appendChild(req.createTextNode(privacy));
+    params.appendChild(node);
+
+    QDomDocument res = this->sendRequest(req, this->createAlbumAction);
+
+    if (this->checkBadResponse(res, this->createAlbumAction))
+        return true;
+    else
+        return false;
+}
+
 void QTransport::getPhotos(QString ownerId, QString albumId, bool alsoLoadIcons)
 {
     qDebug() << __FILE__<<":"<< __LINE__<<":" << __FUNCTION__ << ": accountId=" <<this->accId;
@@ -1216,6 +1331,11 @@ bool QTransport::downloadPhoto(QString url, QString file_name)
 {
     qDebug() << __FILE__<<":"<< __LINE__<<":" << __FUNCTION__ << ": accountId=" <<this->accId;
 
+    QUrl checkUrl(url);
+
+    if (!checkUrl.isValid() || checkUrl.isRelative())
+        return false;
+
     if (!this->checkFunction(CLASS_PHOTOS, GET_PHOTO, this->getPhotoAction))
         return false;
 
