@@ -18,8 +18,8 @@
 /*
  * Datatype functions:
  *
- * Friend: getFriends; gotFriends // done
- * Albums: 3 * getAlbums; gotAlbumList // done
+ * Friend: getFriends; gotFriends // done // done
+ * Albums: 3 * getAlbums; gotAlbumList, createAlbum // done
  * Photos: 2 * getPhotos; gotPhotoList // done
  * Inbox Messages: getInboxMessages; gotInboxMessageList // done
  * Outbox Messages: getOutboxMessages; gotOutboxMessageList // done
@@ -30,7 +30,7 @@ ServiceMgr::ServiceMgr(QObject *parent) :
     QObject(parent), canUpdateFriends(false), canUpdateAlbums(false), canUpdateMessages(false), canUpdateFeeds(false),
     friendsUpdate(0), albumsUpdate(0), photosUpdate(0),
     feedsUpdate(0), messagesUpdate(0),
-    filteredDriver(0), serviceFilter_(0), filterManager_(0), activePanelIndex(-1)
+    serviceFilter_(0), filterManager_(0)
 {
     this->isSkipFriendListUpdate = false;
 
@@ -302,8 +302,7 @@ FriendList ServiceMgr::getFriends(bool isNeedUpdate, bool useSignal)
 
     if (useSignal)
         emit this->updateFriendsNoFilters(this->cachedFriendList, this->friendsUpdate > 0 ? false: true);
-    filterFriendList(cachedFriendList);
-    filterManager_->filterList(cachedFriendList);
+    //filterFriendList(cachedFriendList);
     if (useSignal)
         emit this->updateFriends(this->cachedFriendList, this->friendsUpdate > 0 ? false: true);
 
@@ -340,8 +339,7 @@ void ServiceMgr::gotFriends(QString accountid, FriendList list, bool isLastUpdat
     qSort(this->cachedFriendList.begin(), this->cachedFriendList.end());
 
     emit updateFriendsNoFilters(this->cachedFriendList, (this->friendsUpdate > 0 ? false: true));
-    filterFriendList(cachedFriendList);
-    filterManager_->filterList(cachedFriendList);
+    //filterFriendList(cachedFriendList);
     emit updateFriends(this->cachedFriendList, (this->friendsUpdate > 0 ? false: true));
 
     if (!isLastUpdate)
@@ -367,8 +365,6 @@ AlbumList ServiceMgr::getAlbums(bool isNeedUpdate, bool useSignal)
 
     qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << "(): this->albumsUpdate=" << this->albumsUpdate;
 
-    filterManager_->filterList(ret);
-
     if (useSignal && this->accounts.length() > 0)
         emit this->updateAlbumList(this->accounts.at(0)->getProfile(false), ret, this->albumsUpdate > 0 ? false: true);
 
@@ -407,8 +403,6 @@ AlbumList ServiceMgr::getAlbums(const Friend& curFriend, bool isNeedUpdate, cons
 
     qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << "(): this->albumsUpdate=" << this->albumsUpdate;
 
-    filterManager_->filterList(ret);
-
     if (useSignal)
         emit this->updateAlbumList(curFriend, ret, this->albumsUpdate > 0 ? false: true);
 
@@ -459,10 +453,19 @@ void ServiceMgr::gotAlbumList(QString accountId, QString owner, AlbumList list,
     }
     qDebug() << "islastUpdate=" << isLastUpdate << ", albumsUpdate=" << albumsUpdate << ", accountId=" << accountId << "owner=" << owner;
 
-    filterManager_->filterList(ret);
     emit updateAlbumList(this->getProfile(accountId, owner, false, false, false), ret, this->albumsUpdate > 0 ? false: true);
 }
 
+bool ServiceMgr::createAlbum(QString accountId, QString name, QString description, QString privacy)
+{
+    for (int i = 0; i < this->accounts.length(); i++) {
+        if (this->accounts.at(i)->isDisabled()) continue;
+        if (accountId == this->accounts.at(i)->transport->accountId())
+            return this->accounts.at(i)->transport->createAlbum(name, description, privacy);
+    }
+    return false;
+}
+
 PhotoList ServiceMgr::getPhotos(const Album& album, const bool isNeedUpdate, const bool useSignal, const bool loadIcons)
 {
     bool nUpdate = isNeedUpdate;
@@ -576,7 +579,7 @@ MessageList ServiceMgr::getMessages(bool isNeedUpdate, bool useSignal)
 
     for (int i = 0; i < this->accounts.length(); i++) {
         if (this->accounts.at(i)->isDisabled()) continue;
-        if (isServiceFiltered(accounts[i])) continue;
+        //if (isServiceFiltered(accounts[i])) continue;
 
         MessageList curList = this->accounts.at(i)->getMessageList();
         ret.append(curList);
@@ -598,8 +601,6 @@ MessageList ServiceMgr::getMessages(bool isNeedUpdate, bool useSignal)
         }
     }
 
-    filterManager_->filterList(ret);
-
     if (useSignal)
         emit this->updateMessageList(ret, this->messagesUpdate > 0 ? false: true);
 
@@ -615,19 +616,15 @@ void ServiceMgr::gotMessageList(QString accountId, MessageList list, bool isLast
 
     for (int i = 0; i < this->accounts.length(); i++) {
         if (this->accounts.at(i)->isDisabled()) continue;
-        if (isServiceFiltered(accounts[i]) && !isLastUpdate) continue;
+        //if (isServiceFiltered(accounts[i]) && !isLastUpdate) continue;
         if (this->accounts[i]->transport->accountId() == accountId) {
             this->accounts[i]->setMessageList(list);
-            if (!isServiceFiltered(accounts[i]))
-                ret.append(list);
+            ret.append(list);
             qDebug() << "Add to messages " << list.length() << ". Total:" << ret.length();
         } else {
-            if (!isServiceFiltered(accounts[i]))
-            {
-                MessageList lst = this->accounts[i]->getMessageList();
-                ret.append(lst);
-                qDebug() << "Add to messages " << lst.length() << ". Total:" << ret.length();
-            }
+            MessageList lst = this->accounts[i]->getMessageList();
+            ret.append(lst);
+            qDebug() << "Add to messages " << lst.length() << ". Total:" << ret.length();
         }
     }
 
@@ -635,8 +632,6 @@ void ServiceMgr::gotMessageList(QString accountId, MessageList list, bool isLast
         this->messagesUpdate--;
     qDebug() << "islastUpdate=" << isLastUpdate << ", messagesUpdate=" << messagesUpdate;
 
-    filterManager_->filterList(ret);
-
     emit updateMessageList(ret, (this->messagesUpdate > 0 ? false: true));
 }
 
@@ -1117,6 +1112,9 @@ void ServiceMgr::gotErrorMsg(QString accountId, QErrorMsg msg, QTransport::Actio
     case QTransport::getListMethodsAction:
         prefix += tr("\"Get list of registered methods\"");
         break;
+    case QTransport::createAlbumAction:
+        prefix += tr("\"Create album\"");
+        break;
     case QTransport::getFeedAction:
         prefix += tr("\"Get feed\"");
         this->feedsUpdate--;
@@ -1352,57 +1350,20 @@ void ServiceMgr::gotEventFeed(QString accountId, QEventFeedList list, QEventFeed
     emit this->updateFeed(ret, type, this->feedsUpdate > 0 ? false : true);
 }
 
-void ServiceMgr::changeFilteredService(DriverInfo* driverInfo)
-{
-    filteredDriver = driverInfo;
-    this->cachedFriendList.clear();
-
-    // After changing filtered servce all datatype needs update
-    for (QMap<int, bool>::iterator iter = typeNeedsUpdate.begin(); iter != typeNeedsUpdate.end(); ++iter)
-        *iter = true;
-
-    if (activePanelIndex == -1) {
-        // Update all data
-        updateData();
-    } else {
-        // Update data corresponding current panel
-        const QList<int>& typeList = panelToTypeMap[activePanelIndex];
-        foreach (int type, typeList)
-            updateData(type);
-    }
-}
-
-void ServiceMgr::changeActivePanel(int index)
-{
-    activePanelIndex = index;
-    const QList<int>& typeList = panelToTypeMap[index];
-
-    // Perform deferred data update
-    foreach (int type, typeList)
-        if (typeNeedsUpdate[type])
-            updateData(type);
-}
-
 void ServiceMgr::updateData(int type)
 {
     bool all = (type == -1);
 
-    if ((all && this->canUpdateFriends) ||
-            type == qMetaTypeId<Friend>()) {
+    if (this->canUpdateFriends && (all || type == qMetaTypeId<Friend>())) {
         getFriends(false, true);
-        typeNeedsUpdate[qMetaTypeId<Friend>()] = false;
     }
 
-    if ((all && this->canUpdateMessages) ||
-            type == qMetaTypeId<Message>()) {
+    if (this->canUpdateMessages && (all || type == qMetaTypeId<Message>())) {
         getMessages(false, true);
-        typeNeedsUpdate[qMetaTypeId<Message>()] = false;
     }
 
-    if ((all && this->canUpdateAlbums) ||
-            type == qMetaTypeId<Album>()) {
+    if (this->canUpdateAlbums && (all || type == qMetaTypeId<Album>())) {
         getAlbums(false, true);
-        typeNeedsUpdate[qMetaTypeId<Album>()] = false;
     }
 
     if (all && this->canUpdateFeeds)
@@ -1416,40 +1377,14 @@ void ServiceMgr::updateData(int type)
     }
 }
 
-bool ServiceMgr::isServiceFiltered(const Account* acc) const
-{
-    return filteredDriver && acc->serviceName() != filteredDriver->serviceName;
-}
-
-void ServiceMgr::filterFriendList(FriendList& list) const
-{
-    if (filteredDriver != 0) {
-        QMutableListIterator<Friend> iter(list);
-
-        while (iter.hasNext()) {
-            const Friend& f = iter.next();
-            if (f.serviceId() != filteredDriver->serviceName) {
-                iter.remove();
-            }
-        }
-    }
-}
-
-void ServiceMgr::setPanelToTypeMap(const QMap<int, QList<int> >& m)
-{
-    panelToTypeMap = m;
-}
-
 void ServiceMgr::createFilter()
 {
     serviceFilter_ = new ServiceFilter(this, false, this);
-    connect(serviceFilter_, SIGNAL(serviceSelected(DriverInfo*)), SLOT(changeFilteredService(DriverInfo*)));
+    serviceFilter_->setObjectName("Main service filter");
 
     filterManager_ = new FilterManager(this);
     filterManager_->setObjectName("Main filter manager");
 
-    connect(filterManager_, SIGNAL(stateChanged(int)), SLOT(updateData(int)));
-
     filterManager_->registerFilterableType<Friend>();
     filterManager_->registerFilterableType<Album>();
     filterManager_->registerFilterableType<Message>();
@@ -1483,3 +1418,12 @@ QList<QStatInfo> ServiceMgr::getStats() const
 
     return ret;
 }
+
+bool ServiceMgr::isLocalFriend(const QString& friendId)
+{
+    foreach (Account* account, accounts) {
+        if (account->getProfile(false).ownerId() == friendId)
+            return true;
+    }
+    return false;
+}
