@@ -447,6 +447,18 @@ public:
       */
     PhotoList getPhotosForAlbum(Photo curPhoto);
 
+    /**
+      \brief Create new album.
+
+      \param accounId ID of owner account.
+      \param name Name of album.
+      \param description Description for album.
+      \param privacy Type of privacy settings.
+
+      \return true if album was created successfully, else false.
+      */
+    bool createAlbum(QString accountId, QString name, QString description, QString privacy);
+
     /**
       \brief Load image list for selected album.
 
@@ -491,9 +503,6 @@ public:
     FilterManager* filterManager() const;
     ServiceFilter* serviceFilter() const;
 
-    // Set mapping from panel to type
-    void setPanelToTypeMap(const QMap<int, QList<int> >& m);
-
     bool canUpdateFriends; /**< \brief Service manager can start friend List update independently. */
 
     bool canUpdateAlbums; /**< \brief Service manager can start album List update independently. */
@@ -505,6 +514,13 @@ public:
     //! Get list of statistics.
     QList<QStatInfo> getStats() const;
 
+    /**
+      \brief Check whether given friend id belongs to local account
+      \param accountId Friend id
+      \return true if account local, false otherwise
+      */
+    bool isLocalFriend(const QString& friendId);
+
 private:
     /**
      \brief List of user accounts.
@@ -564,21 +580,10 @@ private:
 
 
     // Filters
-    DriverInfo* filteredDriver;
     ServiceFilter* serviceFilter_;
     FilterManager* filterManager_;
-    int activePanelIndex;
-    QMap<int, bool> typeNeedsUpdate;
-    QMap<int, QList<int> > panelToTypeMap;
-
     void createFilter();
 
-    // Check whether AccountInfo filtered
-    bool isServiceFiltered(const Account* info) const;
-
-    // Filter FriendList with ServiceFilter
-    void filterFriendList(FriendList& list) const;
-
 signals:
     /**
      * @brief Update friends list signal.
@@ -759,9 +764,7 @@ private slots:
     void gotMessageDeleted(const QString& accountId, const QString& messageId);
 
 public slots:
-    void changeFilteredService(DriverInfo* driverInfo);
     void updateData(int type = -1);
-    void changeActivePanel(int index);
 
     /**
      * @brief
