@@ -68,22 +68,22 @@
 <context>
     <name>FilterMessageType</name>
     <message>
-        <location filename="../src/filter/filtermessagetype.cpp" line="62"/>
+        <location filename="../src/filter/filtermessagetype.cpp" line="60"/>
         <source>All messages</source>
         <translation>Все сообщения</translation>
     </message>
     <message>
-        <location filename="../src/filter/filtermessagetype.cpp" line="66"/>
+        <location filename="../src/filter/filtermessagetype.cpp" line="64"/>
         <source>Inbox</source>
         <translation>Входящие</translation>
     </message>
     <message>
-        <location filename="../src/filter/filtermessagetype.cpp" line="71"/>
+        <location filename="../src/filter/filtermessagetype.cpp" line="69"/>
         <source>Sent</source>
         <translation>Отправленные</translation>
     </message>
     <message>
-        <location filename="../src/filter/filtermessagetype.cpp" line="75"/>
+        <location filename="../src/filter/filtermessagetype.cpp" line="73"/>
         <source>Drafts</source>
         <translation>Черновики</translation>
     </message>
@@ -513,7 +513,7 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/datatypes/friend.cpp" line="218"/>
+        <location filename="../src/datatypes/friend.cpp" line="230"/>
         <source>Unknown</source>
         <translation>Неизвестный</translation>
     </message>
@@ -616,128 +616,128 @@
 <context>
     <name>QTransport</name>
     <message>
-        <location filename="../src/qtransport.cpp" line="259"/>
+        <location filename="../src/qtransport.cpp" line="272"/>
         <source>Caught an exception.</source>
         <translation>Произошла ошибка.</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.cpp" line="306"/>
-        <location filename="../src/qtransport.cpp" line="1168"/>
+        <location filename="../src/qtransport.cpp" line="319"/>
+        <location filename="../src/qtransport.cpp" line="1295"/>
         <source>Bad response from driver</source>
         <translation>Некорректный ответ от драйвера</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.cpp" line="368"/>
+        <location filename="../src/qtransport.cpp" line="381"/>
         <source>Unsupported method was called</source>
         <translation>Вызван неподдерживаемый метод</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.cpp" line="369"/>
+        <location filename="../src/qtransport.cpp" line="382"/>
         <source>This method didn&apos;t supported by selected driver</source>
         <translation>Метод не поддерживается выбранным драйвером</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.cpp" line="874"/>
+        <location filename="../src/qtransport.cpp" line="1001"/>
         <source>The friend or album identificators are not equal</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/qtransport.cpp" line="875"/>
+        <location filename="../src/qtransport.cpp" line="1002"/>
         <source>Incorrect identificators</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/qtransport.cpp" line="1128"/>
+        <location filename="../src/qtransport.cpp" line="1255"/>
         <source>Can&apos;t read file to upload</source>
         <translation>Не удалось открыть отправляемый на сервис файл</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.cpp" line="1239"/>
+        <location filename="../src/qtransport.cpp" line="1371"/>
         <source>QTransport::downloadPhotoLost() with nearest &lt; 0</source>
         <translation>QTransport::downloadPhotoLost() с параметром nearest &lt; 0</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.cpp" line="1240"/>
+        <location filename="../src/qtransport.cpp" line="1372"/>
         <source>Wrong arguments of function</source>
         <translation>Неправильные аргументы функции</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="278"/>
+        <location filename="../src/qtransport.h" line="293"/>
         <source>Unable to save settings</source>
         <translation>Не удалось сохранить настройки</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="279"/>
+        <location filename="../src/qtransport.h" line="294"/>
         <source>Authorization problem</source>
         <translation>Проблема авторизации</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="280"/>
+        <location filename="../src/qtransport.h" line="295"/>
         <source>Authorization canceled</source>
         <translation>Авторизация прервана</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="281"/>
+        <location filename="../src/qtransport.h" line="296"/>
         <source>Unable to perform request</source>
         <translation>Невозможно выполнить запрос</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="282"/>
+        <location filename="../src/qtransport.h" line="297"/>
         <source>Server busy</source>
         <translation>Сервер занят</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="283"/>
+        <location filename="../src/qtransport.h" line="298"/>
         <source>One of the parameters missing or invalid</source>
         <translation>Один из параметров пропущен или неверен</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="284"/>
+        <location filename="../src/qtransport.h" line="299"/>
         <source>Captcha</source>
         <translation>Требуется ввод каптчи</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="285"/>
+        <location filename="../src/qtransport.h" line="300"/>
         <source>Bad response from server</source>
         <translation>Некорректный ответ от сервера</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="286"/>
+        <location filename="../src/qtransport.h" line="301"/>
         <source>Network problem</source>
         <translation>Проблема соединения с сервером</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="287"/>
+        <location filename="../src/qtransport.h" line="302"/>
         <source>Empty message</source>
         <translation>Пустое сообщение</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="288"/>
+        <location filename="../src/qtransport.h" line="303"/>
         <source>Operation prohibited by privacy</source>
         <translation>Операция запрещена приватностью</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="289"/>
+        <location filename="../src/qtransport.h" line="304"/>
         <source>Internal Server Error</source>
         <translation>Внутренняя ошибка сервера</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="290"/>
+        <location filename="../src/qtransport.h" line="305"/>
         <source>Can&apos;t save file</source>
         <translation>Не удалось сохранить файл</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="291"/>
+        <location filename="../src/qtransport.h" line="306"/>
         <source>male</source>
         <translation>мужской</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="292"/>
+        <location filename="../src/qtransport.h" line="307"/>
         <source>female</source>
         <translation>женский</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="295"/>
+        <location filename="../src/qtransport.h" line="310"/>
         <source>Incorrect signature</source>
         <translation>Информация об авторизации неверная или устарела</translation>
     </message>
@@ -752,72 +752,72 @@
 <context>
     <name>ServiceMgr</name>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1048"/>
+        <location filename="../src/servicemgr.cpp" line="1044"/>
         <source>During request </source>
         <translation>В ходе запроса </translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1063"/>
+        <location filename="../src/servicemgr.cpp" line="1059"/>
         <source>&quot;Update list of friends&quot;</source>
         <translation>&quot;Обновление списка друзей&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1066"/>
+        <location filename="../src/servicemgr.cpp" line="1062"/>
         <source>&quot;Delete friend from list&quot;</source>
         <translation>&quot;Удаление друга из списка&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1072"/>
+        <location filename="../src/servicemgr.cpp" line="1068"/>
         <source>&quot;Update list of albums&quot;</source>
         <translation>&quot;Обновление списка альбомов&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1078"/>
+        <location filename="../src/servicemgr.cpp" line="1074"/>
         <source>&quot;Update list of images&quot;</source>
         <translation>&quot;Обновление списка изображений&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1081"/>
+        <location filename="../src/servicemgr.cpp" line="1077"/>
         <source>&quot;Update user profile&quot;</source>
         <translation>&quot;Обновление профиля пользователя&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1082"/>
+        <location filename="../src/servicemgr.cpp" line="1078"/>
         <source>Account swiched to offline mode. Please check network settings and try again.</source>
         <translation>Учетная запись переключена в автономный режим. Пожалуйста, проверьте настройки соединения и попробуйте снова.</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1085"/>
+        <location filename="../src/servicemgr.cpp" line="1081"/>
         <source>&quot;Get settings&quot;</source>
         <translation>&quot;Получение настроек&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1088"/>
+        <location filename="../src/servicemgr.cpp" line="1084"/>
         <source>&quot;Set settings&quot;</source>
         <translation>&quot;Применение настроек&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1094"/>
+        <location filename="../src/servicemgr.cpp" line="1090"/>
         <source>&quot;Download image&quot;</source>
         <translation>&quot;Получение изображения&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1097"/>
+        <location filename="../src/servicemgr.cpp" line="1093"/>
         <source>&quot;Upload image&quot;</source>
         <translation>&quot;Загрузка изображения на сервис&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1099"/>
+        <location filename="../src/servicemgr.cpp" line="1095"/>
         <source>&quot;Get comments&quot;</source>
         <translation>&quot;Получение комментариев&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1102"/>
+        <location filename="../src/servicemgr.cpp" line="1098"/>
         <source>&quot;Send comment&quot;</source>
         <translation>&quot;Отправка комментария&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1105"/>
+        <location filename="../src/servicemgr.cpp" line="1101"/>
         <source>&quot;Get list of messages&quot;</source>
         <translation>&quot;Получение сообщений&quot;</translation>
     </message>
@@ -830,32 +830,37 @@
         <translation type="obsolete">&quot;Получение списка отправленных сообщений&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1108"/>
+        <location filename="../src/servicemgr.cpp" line="1104"/>
         <source>&quot;Send message&quot;</source>
         <translation>&quot;Отправка сообщения&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1111"/>
+        <location filename="../src/servicemgr.cpp" line="1107"/>
         <source>&quot;Mark message as read&quot;</source>
         <translation>&quot;Пометка сообщения прочитанным&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1114"/>
+        <location filename="../src/servicemgr.cpp" line="1110"/>
         <source>&quot;Delete message&quot;</source>
         <translation>&quot;Удаление сообщения&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1117"/>
+        <location filename="../src/servicemgr.cpp" line="1113"/>
         <source>&quot;Get list of registered methods&quot;</source>
         <translation>&quot;Получение списка поддерживаемых методов&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1120"/>
+        <location filename="../src/servicemgr.cpp" line="1116"/>
+        <source>&quot;Create album&quot;</source>
+        <translation>Создать альбом</translation>
+    </message>
+    <message>
+        <location filename="../src/servicemgr.cpp" line="1119"/>
         <source>&quot;Get feed&quot;</source>
         <translation>Получение новостей</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="1127"/>
+        <location filename="../src/servicemgr.cpp" line="1126"/>
         <source> from account &quot;%1&quot; the error %2 was caused: </source>
         <translation> от учетной записи &quot;%1&quot; получена ошибка %2: </translation>
     </message>
